@@ -14,6 +14,7 @@ Plots
     :toctree: generated/
 
     plot_ray
+    plot_surface_raw
     plot_surface
     plot_latitude_slice
     plot_longitude_slice
@@ -32,6 +33,8 @@ Plots
     plot_along_coord
     plot_field_coverage
     plot_density
+    plot_scatter
+    plot_centroids
     plot_cappi
     plot_traj
     plot_pos
@@ -72,15 +75,17 @@ Plots
 from .plots import plot_histogram, plot_histogram2, plot_density, plot_scatter
 from .plots import plot_pos, plot_pos_map, plot_sun_hits, plot_antenna_pattern
 from .plots import plot_scatter_comp, plot_quantiles, plot_selfconsistency
-from .plots import plot_selfconsistency_instrument, _plot_time_range
+from .plots import plot_selfconsistency_instrument, plot_centroids
+from .plots import _plot_time_range
 
 from .plots_vol import plot_ppi, plot_ppi_map, plot_rhi, plot_bscope
 from .plots_vol import plot_time_range, plot_cappi, plot_rhi_profile
 from .plots_vol import plot_along_coord, plot_field_coverage, plot_traj
 from .plots_vol import plot_rhi_contour, plot_ppi_contour, plot_ray
-from .plots_vol import plot_fixed_rng, plot_fixed_rng_span, plot_roi_contour, plot_fixed_rng_sun
+from .plots_vol import plot_fixed_rng, plot_fixed_rng_span, plot_roi_contour
+from .plots_vol import plot_fixed_rng_sun
 
-from .plots_grid import plot_surface, plot_latitude_slice
+from .plots_grid import plot_surface_raw, plot_surface, plot_latitude_slice
 from .plots_grid import plot_longitude_slice, plot_latlon_slice
 
 from .plots_spectra import plot_range_Doppler, plot_complex_range_Doppler
